@@ -19,22 +19,41 @@
  * Boston, MA 02111-1307, USA.
  */
 
-#include <config.h>
+#include "config.h"
 
 #include "pango-engine.h"
 #include "pango-engine-private.h"
 #include "pango-impl-utils.h"
 
-PANGO_DEFINE_TYPE_ABSTRACT (PangoEngine, pango_engine,
-			    NULL, NULL,
-			    G_TYPE_OBJECT)
 
-PANGO_DEFINE_TYPE_ABSTRACT (PangoEngineLang, pango_engine_lang,
-			    NULL, NULL,
-			    PANGO_TYPE_ENGINE)
+G_DEFINE_ABSTRACT_TYPE (PangoEngine, pango_engine, G_TYPE_OBJECT);
+
+static void
+pango_engine_init (PangoEngine *self)
+{
+}
+
+static void
+pango_engine_class_init (PangoEngineClass *klass)
+{
+}
+
+
+G_DEFINE_ABSTRACT_TYPE (PangoEngineLang, pango_engine_lang, PANGO_TYPE_ENGINE);
+
+static void
+pango_engine_lang_init (PangoEngineLang *self)
+{
+}
+
+static void
+pango_engine_lang_class_init (PangoEngineLangClass *klass)
+{
+}
+
 
 static PangoCoverageLevel
-pango_engine_shape_real_covers (PangoEngineShape *engine,
+pango_engine_shape_real_covers (PangoEngineShape *engine G_GNUC_UNUSED,
 				PangoFont        *font,
 				PangoLanguage    *language,
 				gunichar          wc)
@@ -48,16 +67,20 @@ pango_engine_shape_real_covers (PangoEngineShape *engine,
   return result;
 }
 
+
+G_DEFINE_ABSTRACT_TYPE (PangoEngineShape, pango_engine_shape, PANGO_TYPE_ENGINE);
+
+static void
+pango_engine_shape_init (PangoEngineShape *klass)
+{
+}
+
 static void
 pango_engine_shape_class_init (PangoEngineShapeClass *class)
 {
   class->covers = pango_engine_shape_real_covers;
 }
 
-PANGO_DEFINE_TYPE_ABSTRACT (PangoEngineShape, pango_engine_shape,
-			    pango_engine_shape_class_init, NULL,
-			    PANGO_TYPE_ENGINE)
-
 void
 _pango_engine_shape_shape (PangoEngineShape *engine,
 			   PangoFont        *font,
@@ -95,8 +118,8 @@ typedef PangoEngineShape PangoFallbackEngine;
 typedef PangoEngineShapeClass PangoFallbackEngineClass;
 
 static void
-fallback_engine_shape (PangoEngineShape *engine,
-		       PangoFont        *font,
+fallback_engine_shape (PangoEngineShape *engine G_GNUC_UNUSED,
+		       PangoFont        *font G_GNUC_UNUSED,
 		       const char       *text,
 		       gint              length,
 		       const PangoAnalysis *analysis,
@@ -107,7 +130,7 @@ fallback_engine_shape (PangoEngineShape *engine,
   int cluster = 0;
   int i;
 
-  n_chars = text ? g_utf8_strlen (text, length) : 0;
+  n_chars = text ? pango_utf8_strlen (text, length) : 0;
 
   pango_glyph_string_set_size (glyphs, n_chars);
 
@@ -140,28 +163,37 @@ fallback_engine_shape (PangoEngineShape *engine,
 
       p = g_utf8_next_char (p);
     }
+
+  if (analysis->level & 1)
+    pango_glyph_string_reverse_range (glyphs, 0, glyphs->num_glyphs);
 }
 
 static PangoCoverageLevel
-fallback_engine_covers (PangoEngineShape *engine,
-			PangoFont        *font,
-			PangoLanguage    *lang,
-			gunichar          wc)
+fallback_engine_covers (PangoEngineShape *engine G_GNUC_UNUSED,
+			PangoFont        *font G_GNUC_UNUSED,
+			PangoLanguage    *lang G_GNUC_UNUSED,
+			gunichar          wc G_GNUC_UNUSED)
 {
   return PANGO_COVERAGE_NONE;
 }
 
+
+static GType pango_fallback_engine_get_type (void);
+
+G_DEFINE_TYPE (PangoFallbackEngine, pango_fallback_engine, PANGO_TYPE_ENGINE_SHAPE);
+
 static void
-fallback_engine_class_init (PangoEngineShapeClass *class)
+pango_fallback_engine_init (PangoFallbackEngine *self)
+{
+}
+
+static void
+pango_fallback_engine_class_init (PangoFallbackEngineClass *class)
 {
   class->covers = fallback_engine_covers;
   class->script_shape = fallback_engine_shape;
 }
 
-static PANGO_DEFINE_TYPE (PangoFallbackEngine, pango_fallback_engine,
-			  fallback_engine_class_init, NULL,
-			  PANGO_TYPE_ENGINE_SHAPE)
-
 PangoEngineShape *
 _pango_get_fallback_shaper (void)
 {
