@@ -19,7 +19,7 @@
  * Boston, MA 02111-1307, USA.
  */
 
-#include <config.h>
+#include "config.h"
 #include "pango-glyph.h"
 
 /*
@@ -37,7 +37,8 @@ static GList *reorder_items_recurse (GList *items, int n_items);
  * directional levels, produce a list in visual order.
  * The original list is unmodified.
  *
- * Returns a #GList of #PangoItem structures in visual order.
+ * Returns: (transfer full) (element-type Pango.Item): a #GList
+ *          of #PangoItem structures in visual order.
  *
  * (Please open a bug if you use this function.
  *  It is not a particularly convenient interface, and the code
